power=function(n=100,pT1=0.5,pC1=0.5,pT2=0.5,pC2=0.5,prev=0.5,alpha=0.025,s=100,c0=0,c1=0,sens=1,spec=1,seed=24091986){
	#n: 	sample size per group and stage
	#pT1: 	event rate in the treatment group for patients from G_1
	#pC1: 	event rate in the control group for patients from G_1
	#pT2: 	event rate in the treatment group for patients from G_2
	#pC2: 	event rate in the control group for patients from G_2	
	#prev:	prevalence of G_1
	#alpha:	global one-sided significance level
	#s:	number of simulated data sets
	#c0:	decision threshold for G_0
	#c1:	decision threshold for G_1
	#sens:	sensitivity of the applied bioassay (Note that even though the case of sensitvity and/or specificity smaller than one was not considered in the manuscript, this simulation code covers the situation.)
	#spec:	specificity of the applied bioassay (Note that even though the case of sensitvity and/or specificity smaller than one was not considered in the manuscript, this simulation code covers the situation.)
	#seed:	simulation seed	
	set.seed(seed)			
	n1t=round(sens*prev*n)		#number of patients from G_1 correctly assigned to G_1 in the treatment group
	n1f=round((1-spec)*(1-prev)*n)	#number of patients from G_2 falsely assigned to G_1 in the treatment group
	n1=n1t+n1f			#total number of patients assigned to G_1
	n2t=round(spec*(1-prev)*n)	#number of patients from G_2 correctly assigned to G_2 in the treatment group
	n2f=round((1-sens)*prev*n)	#number of patients from G_1 correctly assigned to G_1 in the treatment group
	n2=n2t+n2f			#total number of patients assigned to G_2
					#note that it is assumed that false and correct assignments are occur analogously for the control group

	nT1t=rbinom(s,n1t,pT1)		#vector of length s with simulated number of patients from G_1 correctly assigned to G_1 with an event in the treatment group
	nT1f=rbinom(s,n1f,pT2)		#vector of length s with simulated number of patients from G_2 falsely assigned to G_1 with an event in the treatment group
	nC1t=rbinom(s,n1t,pC1)		#vector of length s with simulated number of patients from G_1 correctly assigned to G_1 with an event in the control group
	nC1f=rbinom(s,n1f,pC2)		#vector of length s with simulated number of patients from G_2 falsely assigned to G_1 with an event in the control group
	nT2t=rbinom(s,n2t,pT2)		#vector of length s with simulated number of patients from G_2 correctly assigned to G_2 with an event in the treatment group
	nT2f=rbinom(s,n2f,pT1)		#vector of length s with simulated number of patients from G_1 falsely assigned to G_2 with an event in the treatment group
	nC2t=rbinom(s,n2t,pC2)		#vector of length s with simulated number of patients from G_2 correctly assigned to G_2 with an event in the control group
	nC2f=rbinom(s,n2f,pC1)		#vector of length s with simulated number of patients from G_1 falsely assigned to G_2 with an event in the control group
	
	nT1=nT1t+nT1f			#total number of patients assigned to G_1 with an event in the treatment group
	nC1=nC1t+nC1f			#total number of patients assigned to G_1 with an event in the control group
	nT2=nT2t+nT2f			#total number of patients assigned to G_2 with an event in the treatment group
	nC2=nC2t+nC2f			#total number of patients assigned to G_2 with an event in the control group

	eff1=(nT1-nC1)/n1		#difference in estimated event rates for G_1
	pooled1=(nT1+nC1)/(2*n1)	#pooled event rate in G_1
	z1=rep(0,s)				
	z1[pooled1>0 & pooled1<1]=eff1[pooled1>0 & pooled1<1]/(sqrt(pooled1[pooled1>0 & pooled1<1]*(1-pooled1[pooled1>0 & pooled1<1])*2/n1))
					#first trial stage test statistics for G_1, note that the situation of no events or only events is handled here by setting the test staistics to zero
	p1=1-pnorm(z1)			#first trial stage p-value for G_1

	nT=nT1+nT2			#calculation of estimated event rate and p-value for the tital population
	nC=nC1+nC2
	eff0=(nT-nC)/n
	pooled0=(nT+nC)/(2*n)
	z0=rep(0,s)
	z0[pooled0>0 & pooled0<1]=eff0[pooled0>0 & pooled0<1]/(sqrt(pooled0[pooled0>0 & pooled0<1]*(1-pooled0[pooled0>0 & pooled0<1])*2/n))
	p0=1-pnorm(z0)

	x01=(1:s)[eff0>c0 & eff1>c1]	#vector which contains the IDs of the studies in which it is decided to continue with both populations
	x0=(1:s)[eff0>c0 & eff1<=c1]	#vector which contains the IDs of the studies in which it is decided to continue with G_0 only
	x1=(1:s)[eff0<=c0 & eff1>c1]	#vector which contains the IDs of the studies in which it is decided to continue with G_1 only
	xfut=(1:s)[eff0<=c0 & eff1<=c1]	#vector which contains the IDs of the studies in which it is decided to stop for futility

	#simulation of the second trial stage events for the co-primary or G_0 only case
	nT1t=rbinom(s,n1t,pT1)
	nT1f=rbinom(s,n1f,pT2)
	nC1t=rbinom(s,n1t,pC1)
	nC1f=rbinom(s,n1f,pC2)
	nT2t=rbinom(s,n2t,pT2)
	nT2f=rbinom(s,n2f,pT1)
	nC2t=rbinom(s,n2t,pC2)
	nC2f=rbinom(s,n2f,pC1)
	
	nT1=nT1t+nT1f
	nC1=nC1t+nC1f
	nT2=nT2t+nT2f
	nC2=nC2t+nC2f

	eff12=(nT1-nC1)/n1
	pooled12=(nT1+nC1)/(2*n1)
	z12=rep(0,s)
	z12[pooled12>0 & pooled12<1]=eff12[pooled12>0 & pooled12<1]/(sqrt(pooled12[pooled12>0 & pooled12<1]*(1-pooled12[pooled12>0 & pooled12<1])*2/n1))
	p12=1-pnorm(z12)

	nT=nT1+nT2
	nC=nC1+nC2
	pooled02=(nT+nC)/(2*n)
	eff02=(nT-nC)/n
	z02=rep(0,s)
	z02[pooled02>0 & pooled02<1]=eff02[pooled02>0 & pooled02<1]/(sqrt(pooled02[pooled02>0 & pooled02<1]*(1-pooled02[pooled02>0 & pooled02<1])*2/n))
	p02=1-pnorm(z02)

	#simulation of the second trial stage events for the G_1 only case
	nT1et=rbinom(s,round(sens*prev/(sens*prev+(1-prev)*(1-spec)))*n,pT1)
	nT1ef=rbinom(s,round((1-prev)*(1-spec)/(sens*prev+(1-prev)*(1-spec)))*n,pT2)
	nC1et=rbinom(s,round(sens*prev/(sens*prev+(1-prev)*(1-spec)))*n,pC1)
	nC1ef=rbinom(s,round((1-prev)*(1-spec)/(sens*prev+(1-prev)*(1-spec)))*n,pC2)
	nT1e=nT1et+nT1ef
	nC1e=nC1et+nC1ef
	eff1e=(nT1e-nC1e)/n
	pooled1e=(nT1e+nC1e)/(2*n)
	z1e=rep(0,s)
	z1e[pooled1e>0 & pooled1e<1]=eff1e[pooled1e>0 & pooled1e<1]/(sqrt(pooled1e[pooled1e>0 & pooled1e<1]*(1-pooled1e[pooled1e>0 & pooled1e<1])*2/n))
	p1e=1-pnorm(z1e)
	
	u1=rep(1,s)		#combined local null hypothesis p-value for G_1
	u0=rep(1,s)		#combined local null hypothesis p-value for G_0
	ua=rep(1,s)		#global null hypothesis p-value for the first trial stage
	ub=rep(1,s)		#global null hypothesis p-value for the second trial stage
	u=rep(1,s)		#combined global hypothesis p-value
	#co-primary case
	if (length(x01)>0){
		u0[x01]=1-pnorm(sqrt(1/2)*qnorm(1-p0[x01])+sqrt(1/2)*qnorm(1-p02[x01]))
		u1[x01]=1-pnorm(sqrt(1/2)*qnorm(1-p1[x01])+sqrt(1/2)*qnorm(1-p12[x01]))
		ua[x01]=pmin(2*pmin(p0[x01],p1[x01]),pmax(p0[x01],p1[x01]))
		ub[x01]=pmin(2*pmin(p02[x01],p12[x01]),pmax(p02[x01],p12[x01]))
		u[x01]=1-pnorm(sqrt(1/2)*qnorm(1-ua[x01])+sqrt(1/2)*qnorm(1-ub[x01]))}
	#G_0 only case
	if (length(x0)>0){
		u0[x0]=1-pnorm(sqrt(1/2)*qnorm(1-p0[x0])+sqrt(1/2)*qnorm(1-p02[x0]))
		ua[x0]=pmin(2*pmin(p0[x0],p1[x0]),pmax(p0[x0],p1[x0]))
		ub[x0]=p02[x0]
		u[x0]=1-pnorm(sqrt(1/2)*qnorm(1-ua[x0])+sqrt(1/2)*qnorm(1-ub[x0]))}
	#G_1 only case
	if (length(x1)>0){
		u1[x1]=1-pnorm(sqrt(prev/(1+prev))*qnorm(1-p1[x1])+sqrt(1/(1+prev))*qnorm(1-p1e[x1]))
		ua[x1]=pmin(2*pmin(p0[x1],p1[x1]),pmax(p0[x1],p1[x1]))
		ub[x1]=p1e[x1]
		u[x1]=1-pnorm(sqrt(1/2)*qnorm(1-ua[x1])+sqrt(1/2)*qnorm(1-ub[x1]))}
	#for the futility case, all p-values are equal to 1.

	y=rep(1,s)[u<alpha]				#IDs of studies with a rejection of the global null
	y0=rep(1,s)[u0<alpha & u<alpha]			#IDs of studies with a rejection of the local null for G_0
	y1=rep(1,s)[u1<alpha & u<alpha]			#IDs of studies with a rejection of the local null for G_1
	y01=rep(1,s)[(u1<alpha | u0<alpha) & u<alpha]	#IDs of studies with a rejection of the local null for either G_0 or G_1, or both

	return(c(sum(y)/s,sum(y0)/s,sum(y1)/s,sum(y01)/s,length(x01)/s,length(x0)/s,length(x1)/s,length(xfut)/s))
	#returning a vector with 
	#1. probability for a rejection of the global null
	#2. probability for a rejection of the local null for G_0
	#3. probability for a rejection of the local null for G_1
	#4. probability for a rejection of the local null for either G_0 or G_1, or both
	#5. probability for a selection of both G_0 and G_1
	#6. probability for a selection of G_0 only
	#7. probability for a selection of G_1 only
	#8. probability for a futility stop
}

