(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     19827,        586]
NotebookOptionsPosition[     18822,        552]
NotebookOutlinePosition[     19332,        572]
CellTagsIndexPosition[     19289,        569]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

(* Mathematica Code for determination of optimal decision thresholds
   [aC1,bC1]:\t \tprior interval for event rates in G_1 in the control group

   [aC2,bC2]: \t\tprior interval for event rates in G_2 in the control group

   [aT1,bT1]: \t\tprior interval for event rates in G_1 in the treatment group

   [aT2,bT2]: \t\tprior interval for event rates in G_2 in the treatment group

   n: \t\t\tnumber of patients per group and stage 

   prev: \t\tprevalence of G_1 

   tau0: \t\trelevance threshold for G_0

   tau1:\t\t\trelevance threshold for G_1

   c0:\t \t\tdecision threshold for G_0 to be optimized

   c1:\t\t\tdecision threshold for G_1 to be optimized

   g0[]:\t\t\tderivative of the expected loss given G_0 is wrongly selected

   h0[]:\t\t\tderivative of the expected loss given G_0 is wrongly not selected

   g1[]:\t\t\tderivative of the expected loss given G_1 is wrongly selected

   h1[]:\t\t\tderivative of the expected loss given G_1 is wrongly not selected

   f0[]:\t\t\tderivative of the expected loss given a false decision \
concerning G_0 \t\t\t\toccurred

   f1[]:\t\t\tderivative of the expected loss given a false decision \
concerning G_1 \t\t\t\toccurred

   b[]:\t\t\tfunction that rounds the results on four digits and maps values \
smaller than \t\t\t\t- 1 to -1 and values larger than 1 to 1, respectively

   opt0[]:\t\tyields the root of f0, i.e. the optimal threshold c0*

   opt1[]:\t\tyields the root of f1, i.e. the optimal threshold c1*

   opt[]:\t\t\tyields [c0*,c1*]

Local adaptive method was applied for numerical integration with precision of \
8 digits.

Secant method was applied for numerical root solving with precision of 3 \
digits.*)\
\>", "Text",
 CellChangeTimes->{
  3.63342333128125*^9, {3.63342350384375*^9, 3.633423520828125*^9}, {
   3.633702703875*^9, 3.633702746734375*^9}, {3.633702889515625*^9, 
   3.63370289875*^9}, {3.633702989484375*^9, 3.633703017109375*^9}, {
   3.633703070875*^9, 3.633703072546875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g0", "[", 
   RowBox[{
    RowBox[{"aC1_", "?", "NumericQ"}], ",", 
    RowBox[{"bC1_", "?", "NumericQ"}], ",", 
    RowBox[{"aC2_", "?", "NumericQ"}], ",", 
    RowBox[{"bC2_", "?", "NumericQ"}], ",", 
    RowBox[{"aT1_", "?", "NumericQ"}], ",", 
    RowBox[{"bT1_", "?", "NumericQ"}], ",", 
    RowBox[{"aT2_", "?", "NumericQ"}], ",", 
    RowBox[{"bT2_", "?", "NumericQ"}], ",", 
    RowBox[{"tau0_", "?", "NumericQ"}], ",", 
    RowBox[{"n_", "?", "NumericQ"}], ",", 
    RowBox[{"prev_", "?", "NumericQ"}], ",", 
    RowBox[{"c0_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"prev", "*", 
           RowBox[{"(", 
            RowBox[{"pT1", "-", "pC1"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "prev"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"pT2", "-", "pC2"}], ")"}]}], "-", "tau0"}], ")"}], ")"}],
        "^", 
       RowBox[{"(", "2", ")"}]}]}], "*", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"prev", "*", 
           RowBox[{"(", 
            RowBox[{"pT1", "-", "pC1"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "prev"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"pT2", "-", "pC2"}], ")"}]}]}], ")"}], ")"}], "<", 
       "tau0"}], "]"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c0", "-", " ", "\[IndentingNewLine]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"prev", "*", 
              RowBox[{"(", 
               RowBox[{"pT1", "-", "pC1"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "prev"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"pT2", "-", "pC2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
         "2"}]}], "/", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"prev", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"pT1", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "pT1"}], ")"}]}], "+", 
                RowBox[{"pC1", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "pC1"}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "prev"}], ")"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"pT2", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "pT2"}], ")"}]}], "+", 
                RowBox[{"pC2", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "pC2"}], ")"}]}]}], ")"}]}]}], ")"}], "/",
            "n"}], ")"}]}], ")"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"pT1", ",", "aT1", ",", "bT1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pC1", ",", "aC1", ",", "bC1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pT2", ",", "aT2", ",", "bT2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pC2", ",", "aC2", ",", "bC2"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<LocalAdaptive\>\""}], ",", 
    RowBox[{"PrecisionGoal", "\[Rule]", "8"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6334214053125*^9, 3.63342146715625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h0", "[", 
   RowBox[{
    RowBox[{"aC1_", "?", "NumericQ"}], ",", 
    RowBox[{"bC1_", "?", "NumericQ"}], ",", 
    RowBox[{"aC2_", "?", "NumericQ"}], ",", 
    RowBox[{"bC2_", "?", "NumericQ"}], ",", 
    RowBox[{"aT1_", "?", "NumericQ"}], ",", 
    RowBox[{"bT1_", "?", "NumericQ"}], ",", 
    RowBox[{"aT2_", "?", "NumericQ"}], ",", 
    RowBox[{"bT2_", "?", "NumericQ"}], ",", 
    RowBox[{"tau0_", "?", "NumericQ"}], ",", 
    RowBox[{"n_", "?", "NumericQ"}], ",", 
    RowBox[{"prev_", "?", "NumericQ"}], ",", 
    RowBox[{"c0_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"prev", "*", 
           RowBox[{"(", 
            RowBox[{"pT1", "-", "pC1"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "prev"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"pT2", "-", "pC2"}], ")"}]}], "-", "tau0"}], ")"}], ")"}],
        "^", 
       RowBox[{"(", "2", ")"}]}]}], "*", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"prev", "*", 
           RowBox[{"(", 
            RowBox[{"pT1", "-", "pC1"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "prev"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"pT2", "-", "pC2"}], ")"}]}]}], ")"}], ")"}], ">", 
       "tau0"}], "]"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c0", "-", " ", "\[IndentingNewLine]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"prev", "*", 
              RowBox[{"(", 
               RowBox[{"pT1", "-", "pC1"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "prev"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"pT2", "-", "pC2"}], ")"}]}]}], ")"}]}], ")"}], "^", 
         "2"}]}], "/", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"prev", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"pT1", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "pT1"}], ")"}]}], "+", 
                RowBox[{"pC1", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "pC1"}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "prev"}], ")"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"pT2", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "pT2"}], ")"}]}], "+", 
                RowBox[{"pC2", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "pC2"}], ")"}]}]}], ")"}]}]}], ")"}], "/",
            "n"}], ")"}]}], ")"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"pT1", ",", "aT1", ",", "bT1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pC1", ",", "aC1", ",", "bC1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pT2", ",", "aT2", ",", "bT2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pC2", ",", "aC2", ",", "bC2"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<LocalAdaptive\>\""}], ",", 
    RowBox[{"PrecisionGoal", "\[Rule]", "8"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.633421469796875*^9, 3.6334215188125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g1", "[", 
   RowBox[{
    RowBox[{"aC1_", "?", "NumericQ"}], ",", 
    RowBox[{"bC1_", "?", "NumericQ"}], ",", 
    RowBox[{"aT1_", "?", "NumericQ"}], ",", 
    RowBox[{"bT1_", "?", "NumericQ"}], ",", 
    RowBox[{"tau1_", "?", "NumericQ"}], ",", 
    RowBox[{"n_", "?", "NumericQ"}], ",", 
    RowBox[{"prev_", "?", "NumericQ"}], ",", 
    RowBox[{"c1_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pT1", "-", "pC1"}], ")"}], "-", "tau1"}], ")"}], "^", 
       RowBox[{"(", "2", ")"}]}]}], "*", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"pT1", "-", "pC1"}], ")"}], "<", "tau1"}], "]"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c1", "-", " ", "\[IndentingNewLine]", 
           RowBox[{"(", 
            RowBox[{"pT1", "-", "pC1"}], ")"}]}], ")"}], "^", "2"}]}], "/", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"pT1", 
              RowBox[{"(", 
               RowBox[{"1", "-", "pT1"}], ")"}]}], "+", 
             RowBox[{"pC1", 
              RowBox[{"(", 
               RowBox[{"1", "-", "pC1"}], ")"}]}]}], ")"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"prev", "*", "n"}], ")"}]}]}], ")"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"pT1", ",", "aT1", ",", "bT1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pC1", ",", "aC1", ",", "bC1"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<LocalAdaptive\>\""}], ",", 
    RowBox[{"PrecisionGoal", "\[Rule]", "8"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.633421522234375*^9, 3.633421548421875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h1", "[", 
   RowBox[{
    RowBox[{"aC1_", "?", "NumericQ"}], ",", 
    RowBox[{"bC1_", "?", "NumericQ"}], ",", 
    RowBox[{"aT1_", "?", "NumericQ"}], ",", 
    RowBox[{"bT1_", "?", "NumericQ"}], ",", 
    RowBox[{"tau1_", "?", "NumericQ"}], ",", 
    RowBox[{"n_", "?", "NumericQ"}], ",", 
    RowBox[{"prev_", "?", "NumericQ"}], ",", 
    RowBox[{"c1_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pT1", "-", "pC1"}], ")"}], "-", "tau1"}], ")"}], "^", 
       RowBox[{"(", "2", ")"}]}]}], "*", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"pT1", "-", "pC1"}], ")"}], ">", "tau1"}], "]"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c1", "-", " ", "\[IndentingNewLine]", 
           RowBox[{"(", 
            RowBox[{"pT1", "-", "pC1"}], ")"}]}], ")"}], "^", "2"}]}], "/", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"pT1", 
              RowBox[{"(", 
               RowBox[{"1", "-", "pT1"}], ")"}]}], "+", 
             RowBox[{"pC1", 
              RowBox[{"(", 
               RowBox[{"1", "-", "pC1"}], ")"}]}]}], ")"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"prev", "*", "n"}], ")"}]}]}], ")"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"pT1", ",", "aT1", ",", "bT1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pC1", ",", "aC1", ",", "bC1"}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<LocalAdaptive\>\""}], ",", 
    RowBox[{"PrecisionGoal", "\[Rule]", "8"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6334215520625*^9, 3.633421579203125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f0", "[", 
   RowBox[{
   "aC1_", ",", "bC1_", ",", "aC2_", ",", "bC2_", ",", "aT1_", ",", "bT1_", 
    ",", "aT2_", ",", "bT2_", ",", "tau0_", ",", "n_", ",", "prev_", ",", 
    "c0_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"g0", "[", 
    RowBox[{
    "aC1", ",", "bC1", ",", "aC2", ",", "bC2", ",", "aT1", ",", "bT1", ",", 
     "aT2", ",", "bT2", ",", "tau0", ",", "n", ",", "prev", ",", "c0"}], 
    "]"}], "+", 
   RowBox[{"h0", "[", 
    RowBox[{
    "aC1", ",", "bC1", ",", "aC2", ",", "bC2", ",", "aT1", ",", "bT1", ",", 
     "aT2", ",", "bT2", ",", "tau0", ",", "n", ",", "prev", ",", "c0"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.633421342125*^9, 3.633421347234375*^9}, {
  3.633421583109375*^9, 3.633421704390625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", 
   RowBox[{
   "aC1_", ",", "bC1_", ",", "aT1_", ",", "bT1_", ",", "tau1_", ",", "n_", 
    ",", "prev_", ",", "c1_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"g1", "[", 
    RowBox[{
    "aC1", ",", "bC1", ",", "aT1", ",", "bT1", ",", "tau1", ",", "n", ",", 
     "prev", ",", "c1"}], "]"}], "+", 
   RowBox[{"h1", "[", 
    RowBox[{
    "aC1", ",", "bC1", ",", "aT1", ",", "bT1", ",", "tau1", ",", "n", ",", 
     "prev", ",", "c1"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6334216675625*^9, 3.63342168125*^9}, {
  3.63342171184375*^9, 3.633421729359375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"b", "[", "x_", "]"}], ":=", 
  RowBox[{"Round", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Sign", "[", "x", "]"}], "*", " ", 
     RowBox[{"Min", "[", 
      RowBox[{
       RowBox[{"Abs", "[", "x", "]"}], ",", "1"}], "]"}]}], ",", "0.0001"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"opt0", "[", 
   RowBox[{
    RowBox[{"aC1_", "?", "NumericQ"}], ",", 
    RowBox[{"bC1_", "?", "NumericQ"}], ",", 
    RowBox[{"aC2_", "?", "NumericQ"}], ",", 
    RowBox[{"bC2_", "?", "NumericQ"}], ",", 
    RowBox[{"aT1_", "?", "NumericQ"}], ",", 
    RowBox[{"bT1_", "?", "NumericQ"}], ",", 
    RowBox[{"aT2_", "?", "NumericQ"}], ",", 
    RowBox[{"bT2_", "?", "NumericQ"}], ",", 
    RowBox[{"tau0_", "?", "NumericQ"}], ",", 
    RowBox[{"n_", "?", "NumericQ"}], ",", 
    RowBox[{"prev_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"b", "[", 
   RowBox[{"c0", "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"f0", "[", 
       RowBox[{
       "aC1", ",", "bC1", ",", "aC2", ",", "bC2", ",", "aT1", ",", "bT1", ",",
         "aT2", ",", "bT2", ",", "tau0", ",", "n", ",", "prev", ",", "c0"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"c0", ",", 
        RowBox[{"-", "1"}], ",", "1", ",", 
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"PrecisionGoal", "\[Rule]", "3"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.633421757515625*^9, 3.633421803890625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"opt1", "[", 
   RowBox[{
    RowBox[{"aC1_", "?", "NumericQ"}], ",", 
    RowBox[{"bC1_", "?", "NumericQ"}], ",", 
    RowBox[{"aT1_", "?", "NumericQ"}], ",", 
    RowBox[{"bT1_", "?", "NumericQ"}], ",", 
    RowBox[{"tau1_", "?", "NumericQ"}], ",", 
    RowBox[{"n_", "?", "NumericQ"}], ",", 
    RowBox[{"prev_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"b", "[", 
   RowBox[{"c1", "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{
       "aC1", ",", "bC1", ",", "aT1", ",", "bT1", ",", "tau1", ",", "n", ",", 
        "prev", ",", "c1"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"c1", ",", 
        RowBox[{"-", "1"}], ",", "1", ",", 
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"PrecisionGoal", "\[Rule]", "3"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.633421808234375*^9, 3.633421857796875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"opt", "[", 
   RowBox[{
   "pC1l_", ",", "pC1h_", ",", "pC2l_", ",", "pC2h_", ",", "pT1l_", ",", 
    "pT1h_", ",", "pT2l_", ",", "pT2h_", ",", "tau0_", ",", "tau1_", ",", 
    "n_", ",", "prev_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"opt0", "[", 
     RowBox[{
     "pC1l", ",", "pC1h", ",", "pC2l", ",", "pC2h", ",", "pT1l", ",", "pT1h", 
      ",", "pT2l", ",", "pT2h", ",", "tau0", ",", "n", ",", "prev"}], "]"}], 
    ",", 
    RowBox[{"opt1", "[", 
     RowBox[{
     "pC1l", ",", "pC1h", ",", "pT1l", ",", "pT1h", ",", "tau1", ",", "n", 
      ",", "prev"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6334218680625*^9, 3.633421871296875*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"some", " ", "example"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.633423350109375*^9, 3.63342335721875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opt", "[", 
  RowBox[{
  "0.05", ",", "0.35", ",", "0.2", ",", "0.5", ",", "0.3", ",", "0.6", ",", 
   "0.2", ",", "0.5", ",", "0.05", ",", "0.1", ",", "100", ",", "0.25"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.633421900703125*^9, 3.6334219205625*^9}, {
  3.6334233959375*^9, 3.633423436*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.0455`", ",", 
   RowBox[{"-", "0.0826`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.633423383515625*^9, 3.63342349571875*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.633423345734375*^9, 3.63342334575*^9}}]
},
WindowSize->{716, 847},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.1999999999999, 841.98}},
FrontEndVersion->"9.0 for Microsoft Windows (32-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 1994, 56, 923, "Text"],
Cell[2554, 78, 3565, 102, 232, "Input"],
Cell[6122, 182, 3566, 102, 232, "Input"],
Cell[9691, 286, 1922, 54, 112, "Input"],
Cell[11616, 342, 1920, 54, 112, "Input"],
Cell[13539, 398, 775, 19, 72, "Input"],
Cell[14317, 419, 608, 16, 72, "Input"],
Cell[14928, 437, 303, 10, 31, "Input"],
Cell[15234, 449, 1161, 29, 112, "Input"],
Cell[16398, 480, 925, 24, 92, "Input"],
Cell[17326, 506, 711, 18, 92, "Input"],
Cell[18040, 526, 158, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[18223, 533, 322, 7, 31, "Input"],
Cell[18548, 542, 167, 4, 31, "Output"]
}, Open  ]],
Cell[18730, 549, 88, 1, 31, "Input"]
}
]
*)

(* End of internal cache information *)
